package at.slini204.tttgames.oneko

import android.content.Intent
import android.os.Bundle
import android.provider.Settings
import android.text.Editable
import android.text.TextWatcher
import android.widget.Button
import android.widget.EditText
import android.widget.SeekBar
import android.widget.Toast
import androidx.appcompat.app.AppCompatActivity

class MainActivity : AppCompatActivity() {

    private lateinit var commandInput: EditText
    private lateinit var speedSlider: SeekBar
    private lateinit var speedInput: EditText
    private lateinit var startButton: Button
    private var selectedAnimal: String = "cat"  // Standard Companion
    private val REQUEST_CODE_OVERLAY_PERMISSION = 1001 // Für Overlay-Berechtigung

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_main)

        // Überprüfe, ob die Overlay-Berechtigung vorhanden ist
        if (!Settings.canDrawOverlays(this)) {
            val intent = Intent(Settings.ACTION_MANAGE_OVERLAY_PERMISSION)
            startActivityForResult(intent, REQUEST_CODE_OVERLAY_PERMISSION)
        }

        commandInput = findViewById(R.id.commandInput)
        speedSlider = findViewById(R.id.speedSlider)
        speedInput = findViewById(R.id.speedInput)
        startButton = findViewById(R.id.startButton)

        // Tierauswahl (Buttons)
        findViewById<Button>(R.id.catButton).setOnClickListener { selectedAnimal = "cat" }
        findViewById<Button>(R.id.dogButton).setOnClickListener { selectedAnimal = "dog" }

        // Slider -> Textfeld
        speedSlider.setOnSeekBarChangeListener(object : SeekBar.OnSeekBarChangeListener {
            override fun onProgressChanged(seekBar: SeekBar, progress: Int, fromUser: Boolean) {
                speedInput.setText(progress.toString())
            }

            override fun onStartTrackingTouch(seekBar: SeekBar) {}
            override fun onStopTrackingTouch(seekBar: SeekBar) {}
        })

        // Textfeld -> Slider
        speedInput.addTextChangedListener(object : TextWatcher {
            override fun afterTextChanged(s: Editable?) {
                val value = s.toString().toIntOrNull()
                if (value != null) {
                    speedSlider.progress = value.coerceIn(1, 10)
                }
            }

            override fun beforeTextChanged(s: CharSequence?, start: Int, count: Int, after: Int) {}
            override fun onTextChanged(s: CharSequence?, start: Int, before: Int, count: Int) {}
        })

        //TODO Start-Button klickt -> Companion starten (Warum nur mit button ausführbar???)
        startButton.setOnClickListener {
            val command = commandInput.text.toString()
            val speed = speedSlider.progress

            if (command.startsWith("oneko")) {
                startCompanionOverlay(selectedAnimal, speed)
            } else {
                Toast.makeText(this, "Ungültiger Befehl!", Toast.LENGTH_SHORT).show()
            }
        }
    }

    private fun startCompanionOverlay(animal: String, speed: Int) {
        val intent = Intent(this, OverlayService::class.java)
        intent.putExtra("animal", animal)
        intent.putExtra("speed", speed)
        startService(intent)
        finish()  // App beenden, Overlay bleibt aktiv
    }
}
